@@ -15,18 +15,16 @@ use Padre::Swarm::Identity;
 use Padre::Swarm::Message;
 use Padre::Swarm::Message::Diff;
 use Padre::Util;
-our $VERSION = '0.11';
+our $VERSION = '0.2';
 our @ISA     = 'Wx::Panel';
 
 use Class::XSAccessor
 	accessors => {
-		task      => 'task',
-		service   => 'service',
+		universe  => 'universe',
 		textinput => 'textinput',
 		chatframe => 'chatframe',
 		userlist  => 'userlist',
 		users => 'users',
-		transport => 'transport',
 		label =>'label',
 	},
 	setters => {
@@ -35,7 +33,6 @@ use Class::XSAccessor
 
 sub new {
 	my $class = shift;
-	my $main  = shift;
 	my %args = @_;
 	my $self = $class->SUPER::new(
 		$class->plugin->wx , -1,
@@ -45,8 +42,8 @@ sub new {
 		Wx::wxLC_REPORT
 		| Wx::wxLC_SINGLE_SEL
 	);
-	$self->$_( $args{$_} ) for qw( transport label );
-	$main->bottom->show($self);
+	$self->$_( $args{$_} ) for qw( universe label );
+	Padre->ide->wx->main->bottom->show($self);
 	
 	# build large area for chat output , with a
 	#  single line entry widget for input
@@ -105,7 +102,7 @@ sub new {
 		resource => 'Padre',
 	);
 
-        $self->users( {} );
+	$self->users( {} );
         
 	Wx::Event::EVT_TEXT_ENTER(
                 $self, $text,
@@ -116,6 +113,10 @@ sub new {
 		$text,
 		sub{ $self->on_text_char(@_) },
         );
+        
+    $self->universe->reg_cb( 'enable' , sub { $self->enable(@_) } );
+	$self->universe->reg_cb( 'disable' , sub { $self->disable(@_) } );
+	
 
 	return $self;
 }
@@ -148,10 +149,9 @@ sub view_icon {
 sub enable {
 	my $self     = shift;
 	TRACE( "Enable Chat" ) if DEBUG;
-	TRACE( " main window is " . $self->main ) if DEBUG;
 
 	# Add ourself to the gui;
-	my $main     = $self->main;
+	my $main     = Padre->ide->wx->main;
 	my $bottom   = $self->bottom;
 	my $position = $bottom->GetPageCount;
 	$self->update_userlist;
@@ -166,7 +166,8 @@ sub enable {
 sub disable {
 	my $self = shift;
 	TRACE( 'Disable Chat' ) if DEBUG;
-	my $main = $self->main;
+	$self->universe->send( {type=>'leave', service=>'chat' } );
+	my $main = Padre->ide->wx->main;
 	my $bottom= $main->bottom;
 	my $position = $bottom->GetPageIndex($self);
 	$self->Hide;
@@ -180,7 +181,7 @@ sub disable {
 sub update_userlist {
 	my $self = shift;
 	my $userlist = $self->userlist;
-	my $geo = $self->plugin->geometry;
+	my $geo = $self->universe->geometry;
 	my @users = $geo->get_users();
 	$userlist->DeleteAllItems;
 	foreach my $user ( @users ) {
@@ -217,6 +218,14 @@ sub on_recv {
 
 }
 
+sub on_connect {
+	my $self = shift;
+	$self->universe->send(
+		{type=>'announce',service=>'chat',
+		from=>$self->plugin->identity->nickname 
+	});
+}
+
 sub write_timestamp {
 	my $self = shift;
 	$self->chatframe->AppendText(
@@ -227,7 +236,9 @@ sub write_timestamp {
 sub write_unstyled {
     my ($self,$text) = @_;
     my $style = $self->chatframe->GetDefaultStyle;
-    $style->SetTextColour( Wx::Colour->new(0,0,0) );
+    $style->SetTextColour( 
+		Wx::SystemSettings::GetColour( Wx::wxSYS_COLOUR_WINDOWTEXT ) 
+	);
     $self->chatframe->SetDefaultStyle($style);
     $self->chatframe->AppendText($text);
     
@@ -266,7 +277,6 @@ sub accept_announce {
         $self->users->{$nick} = 1;
     }
      $self->update_userlist;
-    
 }
 
 sub accept_promote {
@@ -284,7 +294,7 @@ sub accept_promote {
 
 sub accept_disco {
 	my ($self,$message) = @_;
-	$self->transport->send( {type=>'promote',service=>'chat'} );
+	$self->universe->send( {type=>'promote',service=>'chat'} );
 }
 
 sub accept_leave {
@@ -318,9 +328,17 @@ sub command_nick {
     
 }
 
+sub command_geo {
+	my $self = shift;
+	my $geo = $self->universe->geometry;
+	foreach my $edge ( $geo->graph->edges ) {
+		$self->write_unstyled( join (' => ' , @$edge) . "\n" );
+	}
+}
+
 sub command_disco {
     my $self = shift;
-    $self->transport->send({type=>'disco'});
+    $self->universe->send({type=>'disco'});
 }
 
 
@@ -334,7 +352,7 @@ sub tell_service {
 			body => $body,
 			type => 'chat',
 		);
-	$self->transport->send($message)
+	$self->universe->send($message)
 }
 
 sub on_text_enter {
@@ -361,7 +379,7 @@ sub on_text_char {
         my ($fragment) = $partial =~ /(\w+)$/;
         return unless $fragment;
         
-        my @users = $self->plugin->geometry->get_users;
+        my @users = $self->universe->geometry->get_users;
         my @possible = grep { $_ =~ /^$fragment/ } @users;
         if ( scalar @possible == 1 ) {
         	my $replace = shift @possible;
@@ -398,8 +416,8 @@ sub accept_diff {
 	my $file = $message->file;
 	my $diff = $message->diff;
 
-	my $current = $self->main->current->document;
-	my $editor = $self->main->current->editor;
+	my $current = Padre::Current->document;
+	my $editor = Padre::Current->editor;
 
 	my $p_dir = $current->project_dir;
 	my $p_name = File::Basename::basename( $p_dir );
@@ -536,6 +554,7 @@ sub derive_rgb {
     my $word   = substr($digest,0,2);
     my $int    = unpack('%S',$word);
     my $hue = 360 * ( $int / 65535 );
+    # TODO - derive differently based on system background colour ?
     my $norm =  hsv2rgb( $hue, 0.8, 0.75 );
     my @rgb =  map { int(255*$_) } @$norm;
     return \@rgb;
