@@ -11,7 +11,7 @@ use Padre::Util     ();
 use Padre::Wx       ();
 use Padre::Constant ();
 
-our $VERSION = '0.11';
+our $VERSION = '0.2';
 our @ISA     = 'Wx::TreeCtrl';
 
 
@@ -21,6 +21,7 @@ our @ISA     = 'Wx::TreeCtrl';
 sub new {
 	my $class = shift;
 	my $panel = shift;
+	my %args = @_;
 	my $self  = $class->SUPER::new(
 		$panel,
 		-1,
@@ -29,7 +30,10 @@ sub new {
 		Wx::wxTR_HIDE_ROOT | Wx::wxTR_SINGLE | Wx::wxTR_FULL_ROW_HIGHLIGHT | Wx::wxTR_HAS_BUTTONS
 			| Wx::wxTR_LINES_AT_ROOT | Wx::wxBORDER_NONE
 	);
-
+	
+	# Yuk - TODO event subscriptions 'after' geometry handles this ?
+	$self->{universe} =  $args{universe} ;
+	
 	# Files that must be skipped
 	$self->{CACHED} = {};
 
@@ -119,6 +123,8 @@ sub new {
 	return $self;
 }
 
+sub universe { $_[0]->{universe} }
+
 # Returns the Directory Panel object reference
 sub parent {
 	$_[0]->GetParent;
@@ -156,8 +162,6 @@ sub refresh {
 	#$_update_subdirs( $self, $root );
 }
 
-sub plugin { Padre::Plugin::Swarm->instance }
-
 # Updates root nodes data to the current project
 # Called when turned beteween projects
 use Data::Dumper;
@@ -169,7 +173,7 @@ sub _update_root_data {
 	my $root = $self->GetRootItem;
 	$self->DeleteChildren($root);
 	my $data = $self->GetPlData($root);
-	my $geo = $self->plugin->geometry;
+	my $geo = $self->universe->geometry;
 	foreach my $user ( $geo->get_users ) {
 		my $user_node = 
 			$self->AppendItem( $root, $user , -1 , -1 ,
@@ -253,7 +257,7 @@ sub _on_tree_item_activated {
 	
 	if ($node_data->{type} eq 'editor' ) {
 		## Another FIXME!
-		$self->plugin->global->transport->send(
+		$self->universe->send(
 			{ type=>'gimme',
 			  resource => $node_data->{resource} }
 		);
